DraggingPoint class

Event indicating a point is being dragged to a new position.

Inheritance

Constructors

DraggingPoint(LatLng point, LatLng newPosition)

Properties

hashCode int
The hash code for this object.
no setterinherited
newPosition LatLng
The current geographical coordinates of the point during dragging.
final
point LatLng
The original geographical coordinates of the point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited