DraggingPointFromLine class

Event indicating a point on a line is being dragged.

Inheritance

Constructors

DraggingPointFromLine(LatLng point)

Properties

hashCode int
The hash code for this object.
no setterinherited
point LatLng
The current geographical coordinates of the point being dragged.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited