Editor class

Represents a state of the editor with a set of points.

Constructors

Editor(List<LatLng> points, {int version = 0})
Creates an Editor instance with the given points.

Properties

hashCode int
The hash code for this object.
no setterinherited
lines List<List<LatLng>>
Converts the points into a list of line segments connecting them.
no setter
points List<LatLng>
The list of geographic coordinates (LatLng) defining the points.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

copyAndIncrementVersion() Editor
Creates a copy of the Editor instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited