StartedDraggingPointFromLine class

Event indicating dragging has started on a point that's part of a line.

Inheritance

Constructors

StartedDraggingPointFromLine(List<LatLng> line, LatLng point)

Properties

hashCode int
The hash code for this object.
no setterinherited
line List<LatLng>
The line segment where the dragging started.
final
point LatLng
The geographical coordinates of the point being dragged.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited