PolarisMapEditor class
Widget responsible for displaying the Polaris map editor.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PolarisMapEditor
Constructors
-
PolarisMapEditor({Key? key, required MapController mapController, PolarisOptions? options, List<
LatLng> initialArea = const [], dynamic onAreaChanged(List<LatLng> area)?, required Widget child}) - Creates a PolarisMapEditor with the specified options and child.
Properties
- child → Widget
-
The widget to display within the map editor.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialArea
→ List<
LatLng> -
The initial area of the map editor.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mapController → MapController
-
The flutter map controller used to control the map.
final
-
onAreaChanged
→ dynamic Function(List<
LatLng> area)? -
Called when the area changes.
final
- options → PolarisOptions
-
Configuration options for the map editor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PolarisMapEditor> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited